pub struct WithSessionMsg<M> {
pub message: ActionMsg<M>,
pub session_key: String,
}Fields
message: ActionMsg<M>session_key: StringTrait Implementations
Sourceimpl<M: Clone> Clone for WithSessionMsg<M>
impl<M: Clone> Clone for WithSessionMsg<M>
Sourcefn clone(&self) -> WithSessionMsg<M>
fn clone(&self) -> WithSessionMsg<M>
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<M: Debug> Debug for WithSessionMsg<M>
impl<M: Debug> Debug for WithSessionMsg<M>
Sourceimpl<'de, M> Deserialize<'de> for WithSessionMsg<M>where
M: Deserialize<'de>,
impl<'de, M> Deserialize<'de> for WithSessionMsg<M>where
M: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<M: JsonSchema> JsonSchema for WithSessionMsg<M>
impl<M: JsonSchema> JsonSchema for WithSessionMsg<M>
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<M: PartialEq> PartialEq for WithSessionMsg<M>
impl<M: PartialEq> PartialEq for WithSessionMsg<M>
Sourceimpl<M> Serialize for WithSessionMsg<M>where
M: Serialize,
impl<M> Serialize for WithSessionMsg<M>where
M: Serialize,
impl<M> StructuralPartialEq for WithSessionMsg<M>