pub struct StoredCredentials {
pub has_natives: bool,
pub verifying_id: CredentialId,
pub records: Vec<CredentialRecord>,
pub account_number: u64,
}Fields
has_natives: boolwhether there are stored native credentials that don’t require a signature
verifying_id: CredentialIdDefault ID used for verification
records: Vec<CredentialRecord>ID and info about every stored credential
account_number: u64Trait Implementations
Sourceimpl Clone for StoredCredentials
impl Clone for StoredCredentials
Sourcefn clone(&self) -> StoredCredentials
fn clone(&self) -> StoredCredentials
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoredCredentials
impl Debug for StoredCredentials
Sourceimpl<'de> Deserialize<'de> for StoredCredentials
impl<'de> Deserialize<'de> for StoredCredentials
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StoredCredentials
impl JsonSchema for StoredCredentials
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StoredCredentials
impl PartialEq for StoredCredentials
Sourceimpl Serialize for StoredCredentials
impl Serialize for StoredCredentials
impl StructuralPartialEq for StoredCredentials